////////////////////////////////////////////////////////////////////////////////
//
//  ct_mouse.h   mouse routines 
//
/////////////////////////////////////////////////////////////////////////////////

// Defines as GLOBALs:
//
//   enum BUTTON_STATE { BUTTON_UP, BUTTON_DOWN } ;
//
//   BUTTON_STATE buttonState = BUTTON_UP;
//
//   WM_MOUSEMOVE sets: 
//
//   xMousePos = LOWORD(lParam);  // horizontal position of cursor 
//   yMousePos = HIWORD(lParam);  // vertical position of cursor 
 

#ifndef CT_MOUSE_H
#define CT_MOUSE_H 

#include "ct_windows.h"

inline bool Button() {
    return buttonState == BUTTON_DOWN; 
}    

inline void GetMouse( int& x, int& y ) {
	x = xMousePos;
    y = yMousePos; 
}

inline void GetMouse(Point& P) {
    // int x, y;
	// GetMouse( x, y );
    // P.x = x;
    // P.y = y;
    GetMouse( P.h, P.v );
}

// Get mouse down spot

inline void GetMouseDownSpot(Point& DownSpot) {
	// wait for button down
	// assume mouse button is up upon entry!
	
	while (!Button()) { };		// idle while awaiting click
	
	GetMouse(DownSpot);		// get spot after mouse down
}


// Get mouse up spot after mouse down

inline void GetMouseUpSpot(Point& UpSpot) {
	// wait for button up
	// assume mouse button is down upon entry!
	
	while (Button()) { };		// idle while awaiting release
	
	GetMouse(UpSpot);			// get spot after mouse up
}

// Await mouse click and return location
// of both mouse down spot and mouse up spot

inline void GetClickPoints(Point& DownSpot, Point& UpSpot) {
	GetMouseDownSpot(DownSpot);
	GetMouseUpSpot(UpSpot);
}

// Await mouse click and return location
// of only mouse up spot

inline void GetClickPoint(Point& UpSpot) {
	Point DownSpot;
	GetMouseDownSpot(DownSpot);
	
	GetMouseUpSpot(UpSpot);
}


#endif  // CT_MOUSE_H

